'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var BigInt = require('./BigInt.cjs');
var Serializer = require('./Serializer.cjs');

const toDateTime = value => {
  if (typeof value === 'string' || isDateObject(value)) {
    const date = new Date(value);
    const timestamp = Math.floor(date.getTime() / 1000);
    return BigInt.toBigInt(timestamp);
  }
  return BigInt.toBigInt(value);
};
const now = () => toDateTime(new Date(Date.now()));
const isDateObject = value => Object.prototype.toString.call(value) === '[object Date]';
const formatDateTime = (value, locales = 'en-US', options = {
  month: 'short',
  day: 'numeric',
  year: 'numeric',
  hour: 'numeric',
  minute: 'numeric'
}) => {
  const date = new Date((value * 1000n).toString());
  return date.toLocaleDateString(locales, options);
};
const mapDateTimeSerializer = serializer => Serializer.mapSerializer(serializer, value => {
  const dateTime = toDateTime(value);
  return dateTime > Number.MAX_SAFE_INTEGER ? dateTime : Number(dateTime);
}, value => toDateTime(value));

exports.formatDateTime = formatDateTime;
exports.mapDateTimeSerializer = mapDateTimeSerializer;
exports.now = now;
exports.toDateTime = toDateTime;
//# sourceMappingURL=DateTime.cjs.map
