'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var PublicKey = require('./PublicKey.cjs');

const addTransactionSignature = (transaction, signature, signerPublicKey) => {
  const maxSigners = transaction.message.header.numRequiredSignatures;
  const signerPublicKeys = transaction.message.accounts.slice(0, maxSigners);
  const signerIndex = signerPublicKeys.findIndex(key => PublicKey.samePublicKey(key, signerPublicKey));
  if (signerIndex < 0) {
    throw new Error('The provided signer is not required to sign this transaction.');
  }
  const newSignatures = [...transaction.signatures];
  newSignatures[signerIndex] = signature;
  return {
    ...transaction,
    signatures: newSignatures
  };
};

exports.addTransactionSignature = addTransactionSignature;
//# sourceMappingURL=Transaction.cjs.map
