import { DataEnum, ScalarEnum } from './Enums';
import type { PublicKey, PublicKeyInput } from './PublicKey';
import type { Serializer, WrapInSerializer } from './Serializer';
import type { Nullable, Option } from './Option';
export type StructToSerializerTuple<T extends object, U extends T> = Array<{
    [K in keyof T]: [K, Serializer<T[K], U[K]>];
}[keyof T]>;
export type DataEnumToSerializerTuple<T extends DataEnum, U extends T> = Array<T extends any ? [
    T['__kind'],
    keyof Omit<T, '__kind'> extends never ? Serializer<Omit<T, '__kind'>, Omit<U, '__kind'>> | Serializer<void> : Serializer<Omit<T, '__kind'>, Omit<U, '__kind'>>
] : never>;
export interface SerializerInterface {
    tuple: <T extends any[], U extends T = T>(items: WrapInSerializer<[...T], [...U]>, description?: string) => Serializer<T, U>;
    vec: <T, U extends T = T>(item: Serializer<T, U>, description?: string) => Serializer<T[], U[]>;
    array: <T, U extends T = T>(item: Serializer<T, U>, size: number, description?: string) => Serializer<T[], U[]>;
    map: <TK, TV, UK extends TK = TK, UV extends TV = TV>(key: Serializer<TK, UK>, value: Serializer<TV, UV>, description?: string) => Serializer<Map<TK, TV>, Map<UK, UV>>;
    set: <T, U extends T = T>(item: Serializer<T, U>, description?: string) => Serializer<Set<T>, Set<U>>;
    option: <T, U extends T = T>(item: Serializer<T, U>, description?: string) => Serializer<Option<T>, Option<U>>;
    nullable: <T, U extends T = T>(item: Serializer<T, U>, description?: string) => Serializer<Nullable<T>, Nullable<U>>;
    struct: <T extends object, U extends T = T>(fields: StructToSerializerTuple<T, U>, description?: string) => Serializer<T, U>;
    enum<T>(constructor: ScalarEnum<T>, description?: string): Serializer<T>;
    dataEnum<T extends DataEnum, U extends T = T>(fields: DataEnumToSerializerTuple<T, U>, description?: string): Serializer<T, U>;
    unit: Serializer<void>;
    bool: Serializer<boolean>;
    u8: Serializer<number>;
    u16: Serializer<number>;
    u32: Serializer<number>;
    u64: Serializer<number | bigint, bigint>;
    u128: Serializer<number | bigint, bigint>;
    i8: Serializer<number>;
    i16: Serializer<number>;
    i32: Serializer<number>;
    i64: Serializer<number | bigint, bigint>;
    i128: Serializer<number | bigint, bigint>;
    f32: Serializer<number>;
    f64: Serializer<number>;
    string: Serializer<string>;
    bytes: Serializer<Uint8Array>;
    publicKey: Serializer<PublicKey | PublicKeyInput, PublicKey>;
}
export declare class NullSerializer implements SerializerInterface {
    private readonly error;
    tuple<T extends any[], U extends T = T>(): Serializer<T, U>;
    vec<T, U extends T = T>(): Serializer<T[], U[]>;
    array<T, U extends T = T>(): Serializer<T[], U[]>;
    map<TK, TV, UK extends TK = TK, UV extends TV = TV>(): Serializer<Map<TK, TV>, Map<UK, UV>>;
    set<T, U extends T = T>(): Serializer<Set<T>, Set<U>>;
    option<T, U extends T = T>(): Serializer<Option<T>, Option<U>>;
    nullable<T, U extends T = T>(): Serializer<Nullable<T>, Nullable<U>>;
    struct<T extends object, U extends T = T>(): Serializer<T, U>;
    enum<T>(): Serializer<T>;
    dataEnum<T extends DataEnum, U extends T = T>(): Serializer<T, U>;
    get unit(): Serializer<void>;
    get bool(): Serializer<boolean>;
    get u8(): Serializer<number>;
    get u16(): Serializer<number>;
    get u32(): Serializer<number>;
    get u64(): Serializer<number | bigint, bigint>;
    get u128(): Serializer<number | bigint, bigint>;
    get i8(): Serializer<number>;
    get i16(): Serializer<number>;
    get i32(): Serializer<number>;
    get i64(): Serializer<number | bigint, bigint>;
    get i128(): Serializer<number | bigint, bigint>;
    get f32(): Serializer<number>;
    get f64(): Serializer<number>;
    get string(): Serializer<string>;
    get bytes(): Serializer<Uint8Array>;
    get publicKey(): Serializer<PublicKey | PublicKeyInput, PublicKey>;
}
