import { SolAmount } from './Amount';
import type { Context } from './Context';
import type { Instruction, WrappedInstruction } from './Instruction';
import type { RpcConfirmTransactionOptions, RpcConfirmTransactionResult, RpcSendTransactionOptions } from './RpcInterface';
import { Signer } from './Signer';
import type { Transaction, TransactionInput, TransactionSignature } from './Transaction';
export type TransactionBuilderItemsInput = WrappedInstruction | WrappedInstruction[] | TransactionBuilder | TransactionBuilder[];
export type TransactionBuilderBuildOptions = Omit<TransactionInput, 'payer' | 'instructions'>;
export type TransactionBuilderSendOptions = {
    build?: Partial<TransactionBuilderBuildOptions>;
    send?: RpcSendTransactionOptions;
    confirm?: Partial<RpcConfirmTransactionOptions>;
};
export type TransactionBuilderSendAndConfirmOptions = TransactionBuilderSendOptions & {
    confirm?: Partial<RpcConfirmTransactionOptions>;
};
export declare class TransactionBuilder {
    protected readonly context: Pick<Context, 'rpc' | 'transactions' | 'payer'>;
    protected readonly items: WrappedInstruction[];
    constructor(context: Pick<Context, 'rpc' | 'transactions' | 'payer'>, items?: WrappedInstruction[]);
    static make(context: Pick<Context, 'rpc' | 'transactions' | 'payer'>, items?: WrappedInstruction[]): TransactionBuilder;
    prepend(input: TransactionBuilderItemsInput): TransactionBuilder;
    append(input: TransactionBuilderItemsInput): TransactionBuilder;
    add(input: TransactionBuilderItemsInput): TransactionBuilder;
    splitAtIndex(index: number): [TransactionBuilder, TransactionBuilder];
    getInstructions(): Instruction[];
    getSigners(): Signer[];
    getBytesCreatedOnChain(): number;
    getRentCreatedOnChain(): Promise<SolAmount>;
    build(options: TransactionBuilderBuildOptions): Transaction;
    buildAndSign(options: TransactionBuilderBuildOptions): Promise<Transaction>;
    send(options?: TransactionBuilderSendOptions): Promise<TransactionSignature>;
    sendAndConfirm(options?: TransactionBuilderSendAndConfirmOptions): Promise<{
        signature: TransactionSignature;
        result: RpcConfirmTransactionResult;
    }>;
    protected parseItems(input: TransactionBuilderItemsInput): WrappedInstruction[];
}
